@@ -260,7 +260,7 @@ static CARD8 wsUsbMap[] = {
 	/* 47 */ KEY_LBrace,	/* [ { */
 	/* 48 */ KEY_RBrace,	/* ] } */
 	/* 49 */ KEY_BSlash,	/* \ | */
-	/* 50 */ KEY_BSlash2,	/* \ _ # ~ on some keyboards */
+	/* 50 */ KEY_BSlash,    /* \ _ # ~ on some keyboards */
 	/* 51 */ KEY_SemiColon,	/* ; : */
 	/* 52 */ KEY_Quote,	/* ' " */
 	/* 53 */ KEY_Tilde,	/* ` ~ */
@@ -312,34 +312,34 @@ static CARD8 wsUsbMap[] = {
 	/* 99 */ KEY_KP_Decimal,	/* Keypad . Del */
 	/* 100 */ KEY_Less,	/* < > on some keyboards */
 	/* 101 */ KEY_Menu,	/* Menu */
-	/* 102 */ KEY_NOTUSED,
+	/* 102 */ KEY_Power,	/* sleep key on Sun USB */
 	/* 103 */ KEY_KP_Equal, /* Keypad = on Mac keyboards */
-	/* 104 */ KEY_NOTUSED,
-	/* 105 */ KEY_NOTUSED,
-	/* 106 */ KEY_NOTUSED,
-	/* 107 */ KEY_NOTUSED,
+	/* 104 */ KEY_F13,
+	/* 105 */ KEY_F14,
+	/* 106 */ KEY_F15,
+	/* 107 */ KEY_F16,
 	/* 108 */ KEY_NOTUSED,
-	/* 109 */ KEY_NOTUSED,
+	/* 109 */ KEY_Power,
 	/* 110 */ KEY_NOTUSED,
 	/* 111 */ KEY_NOTUSED,
 	/* 112 */ KEY_NOTUSED,
 	/* 113 */ KEY_NOTUSED,
 	/* 114 */ KEY_NOTUSED,
 	/* 115 */ KEY_NOTUSED,
-	/* 116 */ KEY_NOTUSED,
-	/* 117 */ KEY_NOTUSED,
-	/* 118 */ KEY_NOTUSED,
-	/* 119 */ KEY_NOTUSED,
-	/* 120 */ KEY_NOTUSED,
-	/* 121 */ KEY_NOTUSED,
-	/* 122 */ KEY_NOTUSED,
-	/* 123 */ KEY_NOTUSED,
-	/* 124 */ KEY_NOTUSED,
-	/* 125 */ KEY_NOTUSED,
-	/* 126 */ KEY_NOTUSED,
-	/* 127 */ KEY_NOTUSED,
-	/* 128 */ KEY_NOTUSED,
-	/* 129 */ KEY_NOTUSED,
+	/* 116 */ KEY_L7,
+	/* 117 */ KEY_Help,
+	/* 118 */ KEY_L3,
+	/* 119 */ KEY_L5,
+	/* 120 */ KEY_L1,
+	/* 121 */ KEY_L2,
+	/* 122 */ KEY_L4,
+	/* 123 */ KEY_L10,
+	/* 124 */ KEY_L6,
+	/* 125 */ KEY_L8,
+	/* 126 */ KEY_L9,
+	/* 127 */ KEY_Mute,
+	/* 128 */ KEY_AudioRaise,
+	/* 129 */ KEY_AudioLower,
 	/* 130 */ KEY_NOTUSED,
 	/* 131 */ KEY_NOTUSED,
 	/* 132 */ KEY_NOTUSED,
@@ -443,7 +443,7 @@ static CARD8 wsUsbMap[] = {
 	/* 230 */ KEY_AltLang,	/* Right Alt, AKA AltGr */
 	/* 231 */ KEY_LMeta,	/* Right Meta XXX */
 };
-#define WS_USB_MAP_SIZE (sizeof(wsUsbMap)/sizeof(unsigned char))
+#define WS_USB_MAP_SIZE (sizeof(wsUsbMap)/sizeof(*wsUsbMap))
 
 static
 TransMapRec wsUsb = {
@@ -452,6 +452,239 @@ TransMapRec wsUsb = {
     wsUsbMap
 };
 
+static CARD8 wsXtMap[] = {
+	/* 0 */ KEY_NOTUSED,
+	/* 1 */ KEY_Escape,
+	/* 2 */ KEY_1,
+	/* 3 */ KEY_2,
+	/* 4 */ KEY_3,
+	/* 5 */ KEY_4,
+	/* 6 */ KEY_5,
+	/* 7 */ KEY_6,
+	/* 8 */ KEY_7,
+	/* 9 */ KEY_8,
+	/* 10 */ KEY_9,
+	/* 11 */ KEY_0,
+	/* 12 */ KEY_Minus,
+	/* 13 */ KEY_Equal,
+	/* 14 */ KEY_BackSpace,
+	/* 15 */ KEY_Tab,
+	/* 16 */ KEY_Q,
+	/* 17 */ KEY_W,
+	/* 18 */ KEY_E,
+	/* 19 */ KEY_R,
+	/* 20 */ KEY_T,
+	/* 21 */ KEY_Y,
+	/* 22 */ KEY_U,
+	/* 23 */ KEY_I,
+	/* 24 */ KEY_O,
+	/* 25 */ KEY_P,
+	/* 26 */ KEY_LBrace,
+	/* 27 */ KEY_RBrace,
+	/* 28 */ KEY_Enter,
+	/* 29 */ KEY_LCtrl,
+	/* 30 */ KEY_A,
+	/* 31 */ KEY_S,
+	/* 32 */ KEY_D,
+	/* 33 */ KEY_F,
+	/* 34 */ KEY_G,
+	/* 35 */ KEY_H,
+	/* 36 */ KEY_J,
+	/* 37 */ KEY_K,
+	/* 38 */ KEY_L,
+	/* 39 */ KEY_SemiColon,
+	/* 40 */ KEY_Quote,
+	/* 41 */ KEY_Tilde,
+	/* 42 */ KEY_ShiftL,
+	/* 43 */ KEY_BSlash,
+	/* 44 */ KEY_Z,
+	/* 45 */ KEY_X,
+	/* 46 */ KEY_C,
+	/* 47 */ KEY_V,
+	/* 48 */ KEY_B,
+	/* 49 */ KEY_N,
+	/* 50 */ KEY_M,
+	/* 51 */ KEY_Comma,
+	/* 52 */ KEY_Period,
+	/* 53 */ KEY_Slash,
+	/* 54 */ KEY_ShiftR,
+	/* 55 */ KEY_KP_Multiply,
+	/* 56 */ KEY_Alt,
+	/* 57 */ KEY_Space,
+	/* 58 */ KEY_CapsLock,
+	/* 59 */ KEY_F1,
+	/* 60 */ KEY_F2,
+	/* 61 */ KEY_F3,
+	/* 62 */ KEY_F4,
+	/* 63 */ KEY_F5,
+	/* 64 */ KEY_F6,
+	/* 65 */ KEY_F7,
+	/* 66 */ KEY_F8,
+	/* 67 */ KEY_F9,
+	/* 68 */ KEY_F10,
+	/* 69 */ KEY_NumLock,
+	/* 70 */ KEY_ScrollLock,
+	/* 71 */ KEY_KP_7,
+	/* 72 */ KEY_KP_8,
+	/* 73 */ KEY_KP_9,
+	/* 74 */ KEY_KP_Minus,
+	/* 75 */ KEY_KP_4,
+	/* 76 */ KEY_KP_5,
+	/* 77 */ KEY_KP_6,
+	/* 78 */ KEY_KP_Plus,
+	/* 79 */ KEY_KP_1,
+	/* 80 */ KEY_KP_2,
+	/* 81 */ KEY_KP_3,
+	/* 82 */ KEY_KP_0,
+	/* 83 */ KEY_KP_Decimal,
+	/* 84 */ KEY_NOTUSED,
+	/* 85 */ KEY_NOTUSED,
+	/* 86 */ KEY_Less,	/* backslash on uk, < on german */
+	/* 87 */ KEY_F11,
+	/* 88 */ KEY_F12,
+	/* 89 */ KEY_NOTUSED,
+	/* 90 */ KEY_NOTUSED,
+	/* 91 */ KEY_NOTUSED,
+	/* 92 */ KEY_NOTUSED,
+	/* 93 */ KEY_NOTUSED,
+	/* 94 */ KEY_NOTUSED,
+	/* 95 */ KEY_NOTUSED,
+	/* 96 */ KEY_NOTUSED,
+	/* 97 */ KEY_NOTUSED,
+	/* 98 */ KEY_NOTUSED,
+	/* 99 */ KEY_NOTUSED,
+	/* 100 */ KEY_NOTUSED,
+	/* 101 */ KEY_NOTUSED,
+	/* 102 */ KEY_NOTUSED,
+	/* 103 */ KEY_NOTUSED,
+	/* 104 */ KEY_NOTUSED,
+	/* 105 */ KEY_NOTUSED,
+	/* 106 */ KEY_NOTUSED,
+	/* 107 */ KEY_NOTUSED,
+	/* 108 */ KEY_NOTUSED,
+	/* 109 */ KEY_NOTUSED,
+	/* 110 */ KEY_NOTUSED,
+	/* 111 */ KEY_NOTUSED,
+	/* 112 */ KEY_NOTUSED,
+	/* 113 */ KEY_NOTUSED,
+	/* 114 */ KEY_NOTUSED,
+	/* 115 */ KEY_NOTUSED,
+	/* 116 */ KEY_NOTUSED,
+	/* 117 */ KEY_NOTUSED,
+	/* 118 */ KEY_NOTUSED,
+	/* 119 */ KEY_NOTUSED,
+	/* 120 */ KEY_NOTUSED,
+	/* 121 */ KEY_NOTUSED,
+	/* 122 */ KEY_NOTUSED,
+	/* 123 */ KEY_NOTUSED,
+	/* 124 */ KEY_NOTUSED,
+	/* 125 */ KEY_NOTUSED,
+	/* 126 */ KEY_NOTUSED,
+	/* 127 */ KEY_Pause,
+	/* 128 */ KEY_NOTUSED,
+	/* 129 */ KEY_NOTUSED,
+	/* 130 */ KEY_NOTUSED,
+	/* 131 */ KEY_NOTUSED,
+	/* 132 */ KEY_NOTUSED,
+	/* 133 */ KEY_NOTUSED,
+	/* 134 */ KEY_NOTUSED,
+	/* 135 */ KEY_NOTUSED,
+	/* 136 */ KEY_NOTUSED,
+	/* 137 */ KEY_NOTUSED,
+	/* 138 */ KEY_NOTUSED,
+	/* 139 */ KEY_NOTUSED,
+	/* 140 */ KEY_NOTUSED,
+	/* 141 */ KEY_NOTUSED,
+	/* 142 */ KEY_NOTUSED,
+	/* 143 */ KEY_NOTUSED,
+	/* 144 */ KEY_NOTUSED,
+	/* 145 */ KEY_NOTUSED,
+	/* 146 */ KEY_NOTUSED,
+	/* 147 */ KEY_NOTUSED,
+	/* 148 */ KEY_NOTUSED,
+	/* 149 */ KEY_NOTUSED,
+	/* 150 */ KEY_NOTUSED,
+	/* 151 */ KEY_NOTUSED,
+	/* 152 */ KEY_NOTUSED,
+	/* 153 */ KEY_NOTUSED,
+	/* 154 */ KEY_NOTUSED,
+	/* 155 */ KEY_NOTUSED,
+	/* 156 */ KEY_KP_Enter,
+	/* 157 */ KEY_RCtrl,
+	/* 158 */ KEY_NOTUSED,
+	/* 159 */ KEY_NOTUSED,
+	/* 160 */ KEY_Mute,
+	/* 161 */ KEY_NOTUSED,
+	/* 162 */ KEY_NOTUSED,
+	/* 163 */ KEY_NOTUSED,
+	/* 164 */ KEY_NOTUSED,
+	/* 165 */ KEY_NOTUSED,
+	/* 166 */ KEY_NOTUSED,
+	/* 167 */ KEY_NOTUSED,
+	/* 168 */ KEY_NOTUSED,
+	/* 169 */ KEY_NOTUSED,
+	/* 170 */ KEY_Print,
+	/* 171 */ KEY_NOTUSED,
+	/* 172 */ KEY_NOTUSED,
+	/* 173 */ KEY_NOTUSED,
+	/* 174 */ KEY_AudioLower,
+	/* 175 */ KEY_AudioRaise,
+	/* 176 */ KEY_NOTUSED,
+	/* 177 */ KEY_NOTUSED,
+	/* 178 */ KEY_NOTUSED,
+	/* 179 */ KEY_NOTUSED,
+	/* 180 */ KEY_NOTUSED,
+	/* 181 */ KEY_KP_Divide,
+	/* 182 */ KEY_NOTUSED,
+	/* 183 */ KEY_Print,
+	/* 184 */ KEY_AltLang,
+	/* 185 */ KEY_NOTUSED,
+	/* 186 */ KEY_NOTUSED,
+	/* 187 */ KEY_NOTUSED,
+	/* 188 */ KEY_NOTUSED,
+	/* 189 */ KEY_NOTUSED,
+	/* 190 */ KEY_NOTUSED,
+	/* 191 */ KEY_NOTUSED,
+	/* 192 */ KEY_NOTUSED,
+	/* 193 */ KEY_NOTUSED,
+	/* 194 */ KEY_NOTUSED,
+	/* 195 */ KEY_NOTUSED,
+	/* 196 */ KEY_NOTUSED,
+	/* 197 */ KEY_NOTUSED,
+	/* 198 */ KEY_NOTUSED,
+	/* 199 */ KEY_Home,
+	/* 200 */ KEY_Up,
+	/* 201 */ KEY_PgUp,
+	/* 202 */ KEY_NOTUSED,
+	/* 203 */ KEY_Left,
+	/* 204 */ KEY_NOTUSED,
+	/* 205 */ KEY_Right,
+	/* 206 */ KEY_NOTUSED,
+	/* 207 */ KEY_End,
+	/* 208 */ KEY_Down,
+	/* 209 */ KEY_PgDown,
+	/* 210 */ KEY_Insert,
+	/* 211 */ KEY_Delete,
+	/* 212 */ KEY_NOTUSED,
+	/* 213 */ KEY_NOTUSED,
+	/* 214 */ KEY_NOTUSED,
+	/* 215 */ KEY_NOTUSED,
+	/* 216 */ KEY_NOTUSED,
+	/* 217 */ KEY_NOTUSED,
+	/* 218 */ KEY_NOTUSED,
+	/* 219 */ KEY_LMeta,
+	/* 220 */ KEY_RMeta,
+	/* 221 */ KEY_Menu,
+};
+#define WS_XT_MAP_SIZE (sizeof(wsXtMap)/sizeof(*wsXtMap))
+
+static
+TransMapRec wsXt = {
+    0,
+    WS_XT_MAP_SIZE,
+    wsXtMap
+};
+
 /* Map for adb keyboards  */
 static CARD8 wsAdbMap[] = {
 	/* 0 */ KEY_A,
@@ -505,14 +738,14 @@ static CARD8 wsAdbMap[] = {
 	/* 48 */ KEY_Tab,
 	/* 49 */ KEY_Space,
 	/* 50 */ KEY_Tilde,
-	/* 51 */ KEY_Delete,
+	/* 51 */ KEY_BackSpace,
 	/* 52 */ KEY_AltLang,
 	/* 53 */ KEY_Escape,
 	/* 54 */ KEY_LCtrl,
-	/* 55 */ KEY_Alt,
+	/* 55 */ KEY_LMeta,
 	/* 56 */ KEY_ShiftL,
 	/* 57 */ KEY_CapsLock,
-	/* 58 */ KEY_LMeta,
+	/* 58 */ KEY_Alt,
 	/* 59 */ KEY_Left,
 	/* 60 */ KEY_Right,
 	/* 61 */ KEY_Down,
@@ -525,7 +758,7 @@ static CARD8 wsAdbMap[] = {
 	/* 68 */ KEY_NOTUSED,
 	/* 69 */ KEY_KP_Plus,
 	/* 70 */ KEY_NOTUSED,
-	/* 71 */ KEY_UNKNOWN,	/* Clear */
+	/* 71 */ KEY_NumLock,	/* Clear */
 	/* 72 */ KEY_NOTUSED, 
 	/* 73 */ KEY_NOTUSED,
 	/* 74 */ KEY_NOTUSED,
@@ -549,7 +782,7 @@ static CARD8 wsAdbMap[] = {
 	/* 92 */ KEY_KP_9,
 	/* 93 */ KEY_NOTUSED,
 	/* 94 */ KEY_NOTUSED,
-	/* 95 */ KEY_UNKNOWN,	/* Keypad ,  */
+	/* 95 */ KEY_KP_Decimal,	/* Keypad ,  */
 	/* 96 */ KEY_F5,
 	/* 97 */ KEY_F6,
 	/* 98 */ KEY_F7,
@@ -559,26 +792,31 @@ static CARD8 wsAdbMap[] = {
 	/* 102 */ KEY_NOTUSED,
 	/* 103 */ KEY_F11,
 	/* 104 */ KEY_NOTUSED,
-	/* 105 */ KEY_NOTUSED,
+	/* 105 */ KEY_Print,
 	/* 106 */ KEY_KP_Enter,
-	/* 107 */ KEY_NOTUSED,
+	/* 107 */ KEY_ScrollLock,
 	/* 108 */ KEY_NOTUSED,
 	/* 109 */ KEY_F10,
 	/* 110 */ KEY_NOTUSED,
 	/* 111 */ KEY_F12,
 	/* 112 */ KEY_NOTUSED,
-	/* 113 */ KEY_NOTUSED,
-	/* 114 */ KEY_NOTUSED,
+	/* 113 */ KEY_Pause,
+	/* 114 */ KEY_Insert,
 	/* 115 */ KEY_Home,
 	/* 116 */ KEY_PgUp,
-	/* 117 */ KEY_NOTUSED,
+	/* 117 */ KEY_Delete,
 	/* 118 */ KEY_F4,
 	/* 119 */ KEY_End,
 	/* 120 */ KEY_F2,
 	/* 121 */ KEY_PgDown,
-	/* 122 */ KEY_F1
+	/* 122 */ KEY_F1,
+	/* 123 */ KEY_NOTUSED,
+	/* 124 */ KEY_NOTUSED,
+	/* 125 */ KEY_NOTUSED,
+	/* 126 */ KEY_NOTUSED,
+	/* 127 */ KEY_Power
 };
-#define WS_ADB_MAP_SIZE (sizeof(wsAdbMap)/sizeof(unsigned char))
+#define WS_ADB_MAP_SIZE (sizeof(wsAdbMap)/sizeof(*wsAdbMap))
 
 static
 TransMapRec wsAdb = {
@@ -587,6 +825,270 @@ TransMapRec wsAdb = {
     wsAdbMap
 };
 
+/* Map for LK201 keyboards  */
+static CARD8 wsLk201Map[] = {
+	/* 0 */ KEY_F1,
+	/* 1 */ KEY_F2,
+	/* 2 */ KEY_F3,
+	/* 3 */ KEY_F4,
+	/* 4 */ KEY_F5,
+	/* 5 */ KEY_NOTUSED,
+	/* 6 */ KEY_NOTUSED,
+	/* 7 */ KEY_NOTUSED,
+	/* 8 */ KEY_NOTUSED,
+	/* 9 */ KEY_NOTUSED,
+	/* 10 */ KEY_NOTUSED,
+	/* 11 */ KEY_NOTUSED,
+	/* 12 */ KEY_NOTUSED,
+	/* 13 */ KEY_NOTUSED,
+	/* 14 */ KEY_F6,
+	/* 15 */ KEY_F7,
+	/* 16 */ KEY_F8,
+	/* 17 */ KEY_F9,
+	/* 18 */ KEY_F10,
+	/* 19 */ KEY_NOTUSED,
+	/* 20 */ KEY_NOTUSED,
+	/* 21 */ KEY_NOTUSED,
+	/* 22 */ KEY_NOTUSED,
+	/* 23 */ KEY_NOTUSED,
+	/* 24 */ KEY_NOTUSED,
+	/* 25 */ KEY_NOTUSED,
+	/* 26 */ KEY_NOTUSED,
+	/* 27 */ KEY_F11,
+	/* 28 */ KEY_F12,
+	/* 29 */ KEY_F13,
+	/* 30 */ KEY_F14,
+	/* 31 */ KEY_NOTUSED,
+	/* 32 */ KEY_NOTUSED,
+	/* 33 */ KEY_NOTUSED,
+	/* 34 */ KEY_NOTUSED,
+	/* 35 */ KEY_NOTUSED,
+	/* 36 */ KEY_NOTUSED,
+	/* 37 */ KEY_NOTUSED,
+	/* 38 */ KEY_Help,
+	/* 39 */ KEY_F16,	/* Do */
+	/* 40 */ KEY_NOTUSED,
+	/* 41 */ KEY_NOTUSED,
+	/* 42 */ KEY_F17,
+	/* 43 */ KEY_L8,	/* F18 */
+	/* 44 */ KEY_L9,	/* F19 */
+	/* 45 */ KEY_L10,	/* F20 */
+	/* 46 */ KEY_NOTUSED,
+	/* 47 */ KEY_NOTUSED,
+	/* 48 */ KEY_NOTUSED,
+	/* 49 */ KEY_NOTUSED,
+	/* 50 */ KEY_NOTUSED,
+	/* 51 */ KEY_NOTUSED,
+	/* 52 */ KEY_Home,	/* Find */
+	/* 53 */ KEY_Insert,	/* Insert Here */
+	/* 54 */ KEY_Delete,	/* Re-move */
+	/* 55 */ KEY_End,	/* Select */
+	/* 56 */ KEY_PgUp,	/* Prev-Screen */
+	/* 57 */ KEY_PgDown,	/* Next-Screen */
+	/* 58 */ KEY_NOTUSED,
+	/* 59 */ KEY_NOTUSED,
+	/* 60 */ KEY_KP_0,
+	/* 61 */ KEY_NOTUSED,
+	/* 62 */ KEY_KP_Decimal,
+	/* 63 */ KEY_KP_Enter,
+	/* 64 */ KEY_KP_1,
+	/* 65 */ KEY_KP_2,
+	/* 66 */ KEY_KP_3,
+	/* 67 */ KEY_KP_4,
+	/* 68 */ KEY_KP_5,
+	/* 69 */ KEY_KP_6,
+	/* 70 */ KEY_KP_Plus,	/* KP Comma */
+	/* 71 */ KEY_KP_7,
+	/* 72 */ KEY_KP_8,
+	/* 73 */ KEY_KP_9,
+	/* 74 */ KEY_KP_Minus,
+	/* 75 */ KEY_L1,	/* PF1 */
+	/* 76 */ KEY_L2,	/* PF2 */
+	/* 77 */ KEY_L3,	/* PF3 */
+	/* 78 */ KEY_L4,	/* PF4 */
+	/* 79 */ KEY_NOTUSED,
+	/* 80 */ KEY_NOTUSED,
+	/* 81 */ KEY_Left,
+	/* 82 */ KEY_Right,
+	/* 83 */ KEY_Down,
+	/* 84 */ KEY_Up,
+	/* 85 */ KEY_NOTUSED,
+	/* 86 */ KEY_NOTUSED,
+	/* 87 */ KEY_NOTUSED,
+	/* 88 */ KEY_ShiftL,
+	/* 89 */ KEY_LCtrl,
+	/* 90 */ KEY_CapsLock,
+	/* 91 */ KEY_Alt, 	/* Compose */
+	/* 92 */ KEY_NOTUSED,
+	/* 93 */ KEY_NOTUSED,
+	/* 94 */ KEY_NOTUSED,
+	/* 95 */ KEY_NOTUSED,
+	/* 96 */ KEY_NOTUSED,
+	/* 97 */ KEY_NOTUSED,
+	/* 98 */ KEY_NOTUSED,
+	/* 99 */ KEY_NOTUSED,
+	/* 100 */ KEY_NOTUSED,
+	/* 101 */ KEY_NOTUSED,
+	/* 102 */ KEY_Delete,
+	/* 103 */ KEY_Enter,
+	/* 104 */ KEY_Tab,
+	/* 105 */ KEY_Escape, /* tilde */
+	/* 106 */ KEY_1,
+	/* 107 */ KEY_Q,
+	/* 108 */ KEY_A,
+	/* 109 */ KEY_Z,
+	/* 110 */ KEY_NOTUSED,
+	/* 111 */ KEY_2,
+	/* 112 */ KEY_W,
+	/* 113 */ KEY_S,
+	/* 114 */ KEY_X,
+	/* 115 */ KEY_Less,
+	/* 116 */ KEY_NOTUSED,
+	/* 117 */ KEY_3,
+	/* 118 */ KEY_E,
+	/* 119 */ KEY_D,
+	/* 120 */ KEY_C,
+	/* 121 */ KEY_NOTUSED,
+	/* 122 */ KEY_4,
+	/* 123 */ KEY_R,
+	/* 124 */ KEY_F,
+	/* 125 */ KEY_V,
+	/* 126 */ KEY_Space,
+	/* 127 */ KEY_NOTUSED,
+	/* 128 */ KEY_5,
+	/* 129 */ KEY_T,
+	/* 130 */ KEY_G,
+	/* 131 */ KEY_B,
+	/* 132 */ KEY_NOTUSED,
+	/* 133 */ KEY_6,
+	/* 134 */ KEY_Y,
+	/* 135 */ KEY_H,
+	/* 136 */ KEY_N,
+	/* 137 */ KEY_NOTUSED,
+	/* 138 */ KEY_7,
+	/* 139 */ KEY_U,
+	/* 140 */ KEY_J,
+	/* 141 */ KEY_M,
+	/* 142 */ KEY_NOTUSED,
+	/* 143 */ KEY_8,
+	/* 144 */ KEY_I,
+	/* 145 */ KEY_K,
+	/* 146 */ KEY_Comma,
+	/* 147 */ KEY_NOTUSED,
+	/* 148 */ KEY_9,
+	/* 149 */ KEY_O,
+	/* 150 */ KEY_L,
+	/* 151 */ KEY_Period,
+	/* 152 */ KEY_NOTUSED,
+	/* 153 */ KEY_0,
+	/* 154 */ KEY_P,
+	/* 155 */ KEY_NOTUSED,
+	/* 156 */ KEY_SemiColon,
+	/* 157 */ KEY_Slash,
+	/* 158 */ KEY_NOTUSED,
+	/* 159 */ KEY_Equal,
+	/* 160 */ KEY_RBrace,
+	/* 161 */ KEY_BSlash,
+	/* 162 */ KEY_NOTUSED,
+	/* 163 */ KEY_Minus,
+	/* 164 */ KEY_LBrace,
+	/* 165 */ KEY_Quote,
+	/* 166 */ KEY_NOTUSED,
+	/* 167 */ KEY_NOTUSED,
+	/* 168 */ KEY_NOTUSED,
+	/* 169 */ KEY_NOTUSED,
+	/* 170 */ KEY_NOTUSED,
+	/* 171 */ KEY_NOTUSED,
+	/* 172 */ KEY_NOTUSED,
+	/* 173 */ KEY_NOTUSED,
+	/* 174 */ KEY_NOTUSED,
+	/* 175 */ KEY_NOTUSED,
+	/* 176 */ KEY_NOTUSED,
+	/* 177 */ KEY_NOTUSED,
+	/* 178 */ KEY_NOTUSED,
+	/* 179 */ KEY_NOTUSED,
+	/* 180 */ KEY_NOTUSED,
+	/* 181 */ KEY_NOTUSED,
+	/* 182 */ KEY_NOTUSED,
+	/* 183 */ KEY_NOTUSED,
+	/* 184 */ KEY_NOTUSED,
+	/* 185 */ KEY_NOTUSED,
+	/* 186 */ KEY_NOTUSED,
+	/* 187 */ KEY_NOTUSED,
+	/* 188 */ KEY_NOTUSED,
+	/* 189 */ KEY_NOTUSED,
+	/* 190 */ KEY_NOTUSED,
+	/* 191 */ KEY_NOTUSED,
+	/* 192 */ KEY_NOTUSED,
+	/* 193 */ KEY_NOTUSED,
+	/* 194 */ KEY_NOTUSED,
+	/* 195 */ KEY_NOTUSED,
+	/* 196 */ KEY_NOTUSED,
+	/* 197 */ KEY_NOTUSED,
+	/* 198 */ KEY_NOTUSED,
+	/* 199 */ KEY_NOTUSED,
+	/* 200 */ KEY_NOTUSED,
+	/* 201 */ KEY_NOTUSED,
+	/* 202 */ KEY_NOTUSED,
+	/* 203 */ KEY_NOTUSED,
+	/* 204 */ KEY_NOTUSED,
+	/* 205 */ KEY_NOTUSED,
+	/* 206 */ KEY_NOTUSED,
+	/* 207 */ KEY_NOTUSED,
+	/* 208 */ KEY_NOTUSED,
+	/* 209 */ KEY_NOTUSED,
+	/* 210 */ KEY_NOTUSED,
+	/* 211 */ KEY_NOTUSED,
+	/* 212 */ KEY_NOTUSED,
+	/* 213 */ KEY_NOTUSED,
+	/* 214 */ KEY_NOTUSED,
+	/* 215 */ KEY_NOTUSED,
+	/* 216 */ KEY_NOTUSED,
+	/* 217 */ KEY_NOTUSED,
+	/* 218 */ KEY_NOTUSED,
+	/* 219 */ KEY_NOTUSED,
+	/* 220 */ KEY_NOTUSED,
+	/* 221 */ KEY_NOTUSED,
+	/* 222 */ KEY_NOTUSED,
+	/* 223 */ KEY_NOTUSED,
+	/* 224 */ KEY_NOTUSED,
+	/* 225 */ KEY_NOTUSED,
+	/* 226 */ KEY_NOTUSED,
+	/* 227 */ KEY_NOTUSED,
+	/* 228 */ KEY_NOTUSED,
+	/* 229 */ KEY_NOTUSED,
+	/* 230 */ KEY_NOTUSED,
+	/* 231 */ KEY_NOTUSED,
+	/* 232 */ KEY_NOTUSED,
+	/* 233 */ KEY_NOTUSED,
+	/* 234 */ KEY_NOTUSED,
+	/* 235 */ KEY_NOTUSED,
+	/* 236 */ KEY_NOTUSED,
+	/* 237 */ KEY_NOTUSED,
+	/* 238 */ KEY_NOTUSED,
+	/* 239 */ KEY_NOTUSED,
+	/* 240 */ KEY_NOTUSED,
+	/* 241 */ KEY_NOTUSED,
+	/* 242 */ KEY_NOTUSED,
+	/* 243 */ KEY_NOTUSED,
+	/* 244 */ KEY_NOTUSED,
+	/* 245 */ KEY_NOTUSED,
+	/* 246 */ KEY_NOTUSED,
+	/* 247 */ KEY_NOTUSED,
+	/* 248 */ KEY_NOTUSED,
+	/* 249 */ KEY_NOTUSED,
+	/* 250 */ KEY_NOTUSED,
+	/* 251 */ KEY_NOTUSED,
+};
+#define WS_LK201_MAP_SIZE (sizeof(wsLk201Map)/sizeof(*wsLk201Map))
+
+static
+TransMapRec wsLk201 = {
+    0,
+    WS_LK201_MAP_SIZE,
+    wsLk201Map
+};
+
 static CARD8 wsSunMap[] = {
 	/* 0x00 */ KEY_Help,
 	/* 0x01 */ KEY_L1,		/* stop */
@@ -636,7 +1138,7 @@ static CARD8 wsSunMap[] = {
 	/* 0x2d */ KEY_Mute,		/* Audio Mute */
 	/* 0x2e */ KEY_KP_Divide,
 	/* 0x2f */ KEY_KP_Multiply,
-	/* 0x30 */ KEY_NOTUSED,
+	/* 0x30 */ KEY_Power,
 	/* 0x31 */ KEY_L5,		/* front */
 	/* 0x32 */ KEY_KP_Decimal,
 	/* 0x33 */ KEY_L6,		/* copy */
@@ -706,7 +1208,7 @@ static CARD8 wsSunMap[] = {
 	/* 0x73 */ KEY_NOTUSED,
 	/* 0x74 */ KEY_NOTUSED,
 	/* 0x75 */ KEY_NOTUSED,
-	/* 0x76 */ KEY_NOTUSED,		/* help */
+	/* 0x76 */ KEY_Help,		/* help */
 	/* 0x77 */ KEY_CapsLock,
 	/* 0x78 */ KEY_LMeta,
 	/* 0x79 */ KEY_Space,
@@ -717,7 +1219,7 @@ static CARD8 wsSunMap[] = {
 	/* 0x7e */ KEY_NOTUSED,
 	/* 0x7f */ KEY_NOTUSED
 };
-#define WS_SUN_MAP_SIZE (sizeof(wsSunMap)/sizeof(unsigned char))
+#define WS_SUN_MAP_SIZE (sizeof(wsSunMap)/sizeof(*wsSunMap))
 
 static
 TransMapRec wsSun = {
@@ -855,9 +1357,12 @@ KbdGetMapping (InputInfoPtr pInfo, KeySymsPtr pKeySyms, CARD8 *pModMap)
            switch (pKbd->wsKbdType) {
 	       case WSKBD_TYPE_PC_XT:
 	       case WSKBD_TYPE_PC_AT:
-                    pKbd->RemapScanCode = ATScancode;
+                    pKbd->scancodeMap = &wsXt;
                     break;
 	       case WSKBD_TYPE_USB:
+#ifdef WSKBD_TYPE_MAPLE
+	       case WSKBD_TYPE_MAPLE:
+#endif
                     pKbd->scancodeMap = &wsUsb;
                     break;
 #ifdef WSKBD_TYPE_ADB	
@@ -865,6 +1370,11 @@ KbdGetMapping (InputInfoPtr pInfo, KeySymsPtr pKeySyms, CARD8 *pModMap)
                     pKbd->scancodeMap = &wsAdb; 
                     break;
 #endif
+#ifdef WSKBD_TYPE_LK201
+	       case WSKBD_TYPE_LK201:
+                    pKbd->scancodeMap = &wsLk201;
+                    break;
+#endif
 #ifdef WSKBD_TYPE_SUN
 #ifdef WSKBD_TYPE_SUN5
 	       case WSKBD_TYPE_SUN5:
